Pulls a single column as a vector, delegating to the underlying lazy tbl.
Arguments
- .data
A
tidybreed_tableobject.- var
Column to pull (tidy-select).
- name
Optional column to use as names.
- ...
Passed to
dplyr::pull().
Pulls a single column as a vector, delegating to the underlying lazy tbl.
A tidybreed_table object.
Column to pull (tidy-select).
Optional column to use as names.
Passed to dplyr::pull().