Skip to contents

Applies dplyr::slice_head() to the underlying lazy tbl and returns a modified tidybreed_table so that further dplyr chains continue to work.

Usage

# S3 method for class 'tidybreed_table'
slice_head(.data, ...)

Arguments

.data

A tidybreed_table object.

...

Passed to dplyr::slice_head() (e.g. n = 10).

Value

A tidybreed_table with the slice applied.