Skip to contents

Applies dplyr::slice_max() to the underlying lazy tbl and returns a modified tidybreed_table so that further dplyr chains continue to work.

Usage

# S3 method for class 'tidybreed_table'
slice_max(.data, order_by, ...)

Arguments

.data

A tidybreed_table object.

order_by

Column or expression to order by (tidy-eval).

...

Passed to dplyr::slice_max().

Value

A tidybreed_table with the slice applied.