Skip to contents

Applies dplyr::slice_tail() to the underlying lazy tbl and returns a modified tidybreed_table so that further dplyr chains continue to work.

Usage

# S3 method for class 'tidybreed_table'
slice_tail(.data, ...)

Arguments

.data

A tidybreed_table object.

...

Passed to dplyr::slice_tail() (e.g. n = 10).

Value

A tidybreed_table with the slice applied.