Applies dplyr::slice_head() to the underlying lazy tbl and returns a
modified tidybreed_table so that further dplyr chains continue to work.
Arguments
- .data
A
tidybreed_tableobject.- ...
Passed to
dplyr::slice_head()(e.g.n = 10).
Applies dplyr::slice_head() to the underlying lazy tbl and returns a
modified tidybreed_table so that further dplyr chains continue to work.
A tidybreed_table object.
Passed to dplyr::slice_head() (e.g. n = 10).